@@ -136,7 +136,7 @@ void ContactEditorPage::installTheme(const QString &themePath)
     mEditorGroupEmbeddedPage->installTheme(newPath);
     mEditorEmbeddedPage->installTheme(newPath);
 
-    for (EditorPage *page : qAsConst(mExtraPage)) {
+    for (EditorPage *page : std::as_const(mExtraPage)) {
         page->installTheme(newPath);
     }
     mDesktopPage->installTheme(newPath);
@@ -197,7 +197,7 @@ void ContactEditorPage::createZip(const QString &themeName, KZip *zip)
     mEditorGroupEmbeddedPage->createZip(themeName, zip);
     mEditorEmbeddedPage->createZip(themeName, zip);
 
-    for (EditorPage *page : qAsConst(mExtraPage)) {
+    for (EditorPage *page : std::as_const(mExtraPage)) {
         page->createZip(themeName, zip);
     }
     mDesktopPage->createZip(themeName, zip);
@@ -205,14 +205,17 @@ void ContactEditorPage::createZip(const QString &themeName, KZip *zip)
 
 void ContactEditorPage::addExtraPage()
 {
-    QString filename = QInputDialog::getText(this, i18n("Filename of extra page"), i18n("Filename:"));
-    if (!filename.trimmed().isEmpty()) {
-        if (!filename.endsWith(QLatin1String(".html")) && !filename.endsWith(QLatin1String(".css")) && !filename.endsWith(QLatin1String(".js"))) {
-            filename += QLatin1String(".html");
+    bool ok = false;
+    QString filename = QInputDialog::getText(this, i18n("Filename of extra page"), i18n("Filename:"), {}, {}, &ok);
+    if (ok) {
+        if (!filename.trimmed().isEmpty()) {
+            if (!filename.endsWith(QLatin1String(".html")) && !filename.endsWith(QLatin1String(".css")) && !filename.endsWith(QLatin1String(".js"))) {
+                filename += QLatin1String(".html");
+            }
+            createExtraPage(filename);
+            mThemeSession->addExtraPage(filename);
+            setChanged(true);
         }
-        createExtraPage(filename);
-        mThemeSession->addExtraPage(filename);
-        setChanged(true);
     }
 }
 
@@ -245,7 +248,7 @@ void ContactEditorPage::storeTheme(const QString &directory)
     mEditorGroupEmbeddedPage->saveTheme(themeDirectory);
     mEditorEmbeddedPage->saveTheme(themeDirectory);
 
-    for (EditorPage *page : qAsConst(mExtraPage)) {
+    for (EditorPage *page : std::as_const(mExtraPage)) {
         page->saveTheme(themeDirectory);
     }
     mDesktopPage->saveTheme(themeDirectory);
