@@ -3,8 +3,7 @@
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef THEMEDEFAULTTEMPLATE_H
-#define THEMEDEFAULTTEMPLATE_H
+#pragma once
 
 #include <PimCommon/TemplateListWidget>
 
@@ -13,4 +12,3 @@ namespace ThemeDefaultTemplate
 Q_REQUIRED_RESULT QVector<PimCommon::defaultTemplate> defaultTemplates();
 }
 
-#endif // THEMEDEFAULTTEMPLATE_H
